(function($) {

	$.ZTFY.I18n = {

		INFO: "Information",
		WARNING: "!! ATTENTION !!",

		ERROR_OCCURED: "Une erreur s'est produite !",
		ERRORS_OCCURED: "Des erreurs se sont produites !",

		BAD_LOGIN_TITLE: "Erreur de connexion !",
		BAD_LOGIN_MESSAGE: "Vos paramètres d'authentification n'ont pas permis d'ouvrir de session ; veuillez vérifier ces paramètres ou contacter l'administrateur du site.",

		CONFIRM: "Confirmation",
		CONFIRM_REMOVE: "La suppression de ce contenu ne pourra pas être annulée. Confirmez-vous ?",

		NO_UPDATE: "Aucune modification n'a été appliquée.",
		DATA_UPDATED: "Modifications enregistrées.",

		MISSING_OVERLAY: "Le plug-in JQuery « overlay » est nécessaire ; veuillez inclure les ressources JQuery-tools dans votre page !",

		DATATABLE_sProcessing:     "Traitement en cours...",
		DATATABLE_sSearch:         "Filtrer&nbsp;:",
		DATATABLE_sLengthMenu:     "Afficher _MENU_ &eacute;l&eacute;ments par page",
		DATATABLE_sInfo:           "Affichage de l'&eacute;lement _START_ &agrave; _END_ sur _TOTAL_ &eacute;l&eacute;ments",
		DATATABLE_sInfoEmpty:      "Affichage de l'&eacute;lement 0 &agrave; 0 sur 0 &eacute;l&eacute;ments",
		DATATABLE_sInfoFiltered:   "(filtr&eacute; de _MAX_ &eacute;l&eacute;ments au total)",
		DATATABLE_sInfoPostFix:    "",
		DATATABLE_sLoadingRecords: "Chargement en cours...",
		DATATABLE_sZeroRecords:    "Aucun &eacute;l&eacute;ment &agrave; afficher",
		DATATABLE_sEmptyTable:     "Aucune donnée disponible dans le tableau",
		DATATABLE_oPaginate_sFirst:      "Premier",
		DATATABLE_oPaginate_sPrevious:   "Pr&eacute;c&eacute;dent",
		DATATABLE_oPaginate_sNext:       "Suivant",
		DATATABLE_oPaginate_sLast:       "Dernier",
		DATATABLE_oAria_sSortAscending:  ": activer pour trier la colonne par ordre croissant",
		DATATABLE_oAria_sSortDescending: ": activer pour trier la colonne par ordre décroissant"

	}

})(jQuery);
